# Code to read exported CoMPS Forecast Grid (CFG) files. Be sure to include "reader.py" in the same
# folder as any program that reads a .cfg file.

import matplotlib.pyplot as plt
import cartopy.crs as ccrs
import cartopy.feature as cf
from matplotlib.colors import *
import numpy as np
from reader import *


forecast = ForecastGrid("08-01-2023 00Z Run Storm Mode Forecast 08-04-2023 12Z.cfg")
print(forecast.min())
print(forecast.max())

colors = [(1, 0, 0), (0.75, 0.75, 0.75), (0, 0, 1)]
n_bins = [100]
cmap_name = 'my_list'

ax = plt.axes(projection = ccrs.Mercator())
ax.set_title("CFG Example")
ax.coastlines()
ax.set_global()
ax.set_extent([forecast.longitude[0], forecast.longitude[-1], forecast.latitude[0], forecast.latitude[-1]], crs=ccrs.PlateCarree())
ax.add_feature(cf.COASTLINE)
ax.add_feature(cf.STATES)

for n_bin in n_bins:
    cm = LinearSegmentedColormap.from_list(cmap_name, colors, N=n_bin)
    im = ax.imshow(forecast.data, interpolation='nearest', origin='lower', cmap=cm, vmin = 0, vmax = 1)
    cp = ax.contourf(forecast.longitude, forecast.latitude, forecast.data, transform=ccrs.PlateCarree(), cmap=cm, vmin = 0, vmax = 1, levels=100)
    cb = plt.colorbar(im, ax=ax, orientation="horizontal")
    cb.set_ticks([0, 0.5, 1.0])
    cb.set_ticklabels(["Isolated", "Mixed", "Linear"])

#plt.show()
plt.savefig("Test.png")
plt.clf()
