import numpy as np

class ForecastGrid():
    def __init__(self, fileName):
        pointer = open(fileName, 'rb')
        raw = pointer.read()

        self.__version__ = str(raw[3]) + '.' + str(raw[4]) + '.' + str(raw[5])

        latitudeFactor = raw[6]
        longitudeFactor = raw[7]
        dataFactor = raw[8]
        longitudeSize = raw[9]
        latitudeSize = raw[10]
        dataSize = raw[11]
        row = int.from_bytes(raw[12:14], "big")
        column = int.from_bytes(raw[14:16], "big")

        i = 16

        _mask = np.zeros([row, column])

        self.latitude = np.zeros([row])
        self.longitude = np.zeros([column])
        self.data = np.ma.array(_mask, mask=list(_mask))

        r = 0

        while (r < row):
            self.latitude[r] = int.from_bytes(raw[i:i+latitudeSize], "big") / (10**latitudeFactor)

            r = r + 1
            i = i + latitudeSize

        c = 0

        while (c < column):
            self.longitude[c] = int.from_bytes(raw[i:i+longitudeSize], "big") / (10**longitudeFactor)

            c = c + 1
            i = i + longitudeSize

        r = 0
        c = 0

        missingValue = (256**dataSize)-1

        for j in range(i, len(raw), dataSize):
            entry = int.from_bytes(raw[j:j+dataSize], "big")

            if (entry == missingValue):
                self.data[r, c] = 0
                self.data.mask[r, c] = True
            else:
                entry = entry / (10**dataFactor)

                self.data[r, c] = entry

            c = c + 1

            if (c >= column):
                r = r + 1
                c = 0

    def max(self):
        return self.data.max()

    def min(self):
        return self.data.min()

    def mean(self):
        return self.data.mean()


if (__name__ == "__main__"):
    print('Cannot run this file. Please run the file "CFG.py" in this folder')

